(* $Id: godi_wget_handler.ml 712 2007-07-30 23:15:47Z gerd $ *)

open Godi_types

class wget_handler url : file_handler =
  (* We can assume that [url] is always absolute! *)
object
  method url = url

  method list con () =
    failwith "Cannot list remote files (restriction of boot_console)"

  method get con name =
    assert(not (String.contains name '/'));
    let tdir = Godi_file.allocate_tmpdir() in
    let tfile = Filename.concat (Godi_file.tmpdir_path tdir) name in
    let eff_url =
      if url.[ String.length url - 1 ] = '/' then
	url ^ name
      else
	url ^ "/" ^ name in
    try
      Godi_exec.call_cmd
	~stdout:con.protocol
	~stderr:con.protocol
	~interactivity:con.interactivity
	( Godi_query.wget(),
	  [| "-nv";
	     "-t";
	     "3";
	     "-O";
	     tfile;
	     "--no-glob";
	     "--no-cookies";
	     eff_url
	  |]
	);
      (tfile, Some (fun () -> Godi_file.release_tmpdir tdir))
    with
      | Godi_exec.Command_not_found s ->
	  raise(File_handler_error("Command not found: " ^ s))
      | Godi_exec.Command_failure (s,_,_) ->
	  raise(File_handler_error("Command not successful: " ^ s))
end


let init() =
  Godi_file_handler.register "http" (new wget_handler);
  Godi_file_handler.register "ftp" (new wget_handler)

